Solves the optimization problem needed to create approximate SDP knockoffs
MFKnockoffs.knocks.solve_asdp(Sigma, nBlocks = 10, cores = 1,
gaptol = 1e-06, maxit = 1000)A positive-definite correlation matrix
Number of blocks in the block-diagonal approximation of Sigma (default: 10)
Number of cores used to solve the smaller SDPs (default: 1)
Tolerance for duality gap as a fraction of the value of the objective functions (default 1e-6)
The maximum number of iterations for the solver (default: 1000)
The solution \(s\) to the semidefinite programming problem defined above
Solves the following two-step semidefinite programming problem:
(step 1) $$ \mathrm{maximize} \; \mathrm{sum}(s) \quad \mathrm{subject} \; \mathrm{to:} \; 0 <= s <= 1, \; 2 \Sigma_{\mathrm{approx}} - \mathrm{diag}(s) >= 0$$
(step 2) $$ \mathrm{maximize} \; \gamma \quad \mathrm{subject} \; \mathrm{to:} \; \mathrm{diag}(\gamma s) <= 2 \Sigma$$
If the matrix Sigma supplied by the user is a non-scaled covariance matrix (i.e. its diagonal entries are not all equal to 1), then the appropriate scaling is applied before solving the SDP defined above. The result is then scaled back before being returned, as to match the original scaling of the covariance matrix supplied by the user.
Other Optimize knockoffs: MFKnockoffs.knocks.solve_equi,
MFKnockoffs.knocks.solve_sdp